Thank you for contributing to this project! Before you submit a Pull Request:

* Be sure to read the `contribution guidelines`_
* refer to the `issue`_ that describes the problem you want to address/solve or,
* if no issue exists, directly describe the problem in your Pull Request
* summarize the approach used to address the issue


.. _contribution guidelines: https://github.com/stain/signposting/blob/latest/docs/CONTRIBUTING.rst
.. _issue: https://github.com/stain/signposting/issues
